@@ -289,7 +289,7 @@ class QueryManager:
                                      request_args=request_args)
         except Exception as e:
             logger.error(e, exc_info=True)
-            return "Bad request error", 500, {}
+            return "Bad request error"
 
     def put_resource(self, **kwargs):
         """Handle a PUT method to update a resource
@@ -298,14 +298,13 @@ class QueryManager:
             dict: The response of the request as JSON format
         """
         resource_uri = self.build_instance_uri(kwargs[ID_KEY])
-        body = kwargs["body"]
-        body.id = resource_uri
-
+        body = kwargs["body"].dict()
+        body["id"] = resource_uri            
         try:
             username = kwargs["user"]
         except Exception:
             logger.error("Missing username", exc_info=True)
-            return "Bad request: missing username", 400, {}
+            return "Bad request: missing username"
 
         # DELETE QUERY
         request_args_delete: Dict[str, str] = {
@@ -318,7 +317,7 @@ class QueryManager:
             self.delete_query(request_args_delete)
         except:
             logger.error("Exception occurred", exc_info=True)
-            return "Error deleting query", 407, {}
+            return "Error deleting query"
 
         # INSERT QUERY
         body_json = self.json_to_jsonld(body)
@@ -332,9 +331,9 @@ class QueryManager:
             "g": self.generate_graph(username)
         }
         if self.insert_query(request_args=request_args):
-            return body, 201, {}
+            return body
         else:
-            return "Error inserting query", 407, {}
+            return "Error inserting query"
 
     def delete_resource(self,
                         id: str,
@@ -379,12 +378,13 @@ class QueryManager:
             body.type.append(rdf_type_uri)
         else:
             body.type = [rdf_type_uri]
-        body.id = generate_new_id()
+        body = body.dict()
+        body[ID_KEY] = generate_new_id()
         self.traverse_obj(body, user)
         insert_response = self.insert_all_resources(body, user)
 
         if insert_response:
-            return body, 201, {}
+            return body
         else:
             return "Error inserting resource", 407, {}
 
@@ -422,10 +422,13 @@ class QueryManager:
             raise e
 
         logger.debug("response: {}".format(result))
-        if "resource" in request_args and not skip_id_framing:
-            return self.frame_results(result, owl_class_uri,
-                                      request_args["resource"])
-        return self.frame_results(result, owl_class_uri)
+        try:
+            if "resource" in request_args and not skip_id_framing:
+                return self.frame_results(result, owl_class_uri,
+                                        request_args["resource"])
+            return self.frame_results(result, owl_class_uri)
+        except Exception as e:
+            raise e
 
     def overwrite_endpoint_context(self, endpoint_context: dict):
         """Overwrite the endpoint context
@@ -455,7 +458,8 @@ class QueryManager:
             response_dict = json.loads(response)
         except Exception:
             glogger.error("json serialize failed", exc_info=True)
-            return []
+            raise Exception("json serialize failed")
+            
         if len(response_dict) == 0:
             #Fuseki sometimes return a json with graph and something not...
             if "@id" in response_dict and '@graph' not in response_dict:
@@ -469,7 +473,7 @@ class QueryManager:
         if '@graph' in response_dict:
             response_graph = response_dict['@graph']
         else:
-            response_graph = {}
+            response_graph = response_dict
 
         frame = {"@context": response_context, "@type": owl_class_uri}
         # if owl_resource_iri is set, the user is requesting a specific resource and we must add it to the frame
@@ -520,7 +524,7 @@ class QueryManager:
         -------
 
         '''
-        for key, value in body.__dict__.items():
+        for key, value in body.items():
             if key != "openapi_types" and key != "attribute_map":
                 if isinstance(value, list):
                     for inner_values in value:
@@ -570,7 +574,7 @@ class QueryManager:
         Returns:
             dict: The resource in JSON-LD
         """
-        resource_dict = resource.to_dict()
+        resource_dict = resource
         resource_dict["id"] = self.build_instance_uri(resource_dict["id"])
         resource_dict['@context'] = self.context
         resource_json = json.dumps(resource_dict)
@@ -588,8 +592,8 @@ class QueryManager:
         query_string = f'{request_args["prefixes"]}' \
               f'INSERT DATA {{ GRAPH <{request_args["g"]}> ' \
               f'{{ {request_args["triples"]} }} }}'
-
         try:
+            print(query_string)
             self.sparql.update(query_string)
         except Exception as err:
             glogger.error("Exception occurred", exc_info=True)
@@ -614,7 +618,7 @@ class QueryManager:
             self.sparql.update(query_string)
         except Exception as e:
             glogger.error("Exception occurred", exc_info=True)
-            return "Error delete query", 405, {}
+            return "Error delete query"
 
         if request_args["delete_incoming_relations"]:
             query_string_reverse = f'' \
@@ -627,8 +631,8 @@ class QueryManager:
                 self.sparql.update(query_string_reverse)
             except Exception as e:
                 glogger.error("Exception occurred", exc_info=True)
-                return "Error delete query", 405, {}
-        return "Deleted", 202, {}
+                return "Error delete query"
+        return "Deleted"
 
     def get_insert_query(self, resource_json: str):
         """Convert the JSON-LD to triple to be inserted"""
@@ -775,11 +779,14 @@ class QueryManager:
                 logger.error("Parameters given: {} ".format(request_args))
                 raise e
         # Rewrite query using pagination
+        print(request_args)
         if PER_PAGE_KEY in request_args and "offset" in request_args:
+            print("here")
             rewritten_query = rewritten_query.replace(
                 "LIMIT 100", "LIMIT {}".format(request_args[PER_PAGE_KEY]))
             rewritten_query = rewritten_query.replace(
                 "OFFSET 0", "OFFSET {}".format(request_args["offset"]))
+        print(rewritten_query)
         logger.info(rewritten_query)
         return self.sparql.query(rewritten_query)
 
